@@ -18,7 +18,7 @@
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *)
 
-(* $Id: ssl.ml,v 1.20 2005/06/02 14:13:49 smimram Exp $ *)
+(* $Id: ssl.ml 2683 2006-08-28 14:53:19Z smimram $ *)
 
 type protocol =
   | SSLv2
@@ -108,6 +108,8 @@ let _ =
 
 external init : bool -> unit = "ocaml_ssl_init"
 
+external get_error_string : unit -> string = "ocaml_ssl_get_error_string"
+
 external crypto_num_locks : unit -> int = "ocaml_ssl_crypto_num_locks"
 
 let thread_id_function = ref None
@@ -134,6 +136,8 @@ external create_context : protocol -> context_type -> context = "ocaml_ssl_creat
 
 external use_certificate : context -> string -> string -> unit = "ocaml_ssl_ctx_use_certificate"
 
+external set_password_callback : context -> (bool -> string) -> unit = "ocaml_ssl_ctx_set_default_passwd_cb"
+
 external embed_socket : Unix.file_descr -> context -> socket = "ocaml_ssl_embed_socket"
 
 external set_cipher_list : context -> string -> unit = "ocaml_ssl_ctx_set_cipher_list"
@@ -187,16 +191,8 @@ external verify : socket -> unit = "ocaml_ssl_verify"
 
 external write : socket -> string -> int -> int -> int = "ocaml_ssl_write"
 
-let write ssl buf ofs len =
-  ignore (Unix.select [] [file_descr_of_socket ssl] [] (-1.));
-  write ssl buf ofs len
-
 external read : socket -> string -> int -> int -> int = "ocaml_ssl_read"
 
-let read ssl buf ofs len =
-  ignore (Unix.select [file_descr_of_socket ssl] [] [] (-1.));
-  read ssl buf ofs len
-
 external accept : socket -> unit = "ocaml_ssl_accept"
 
 external flush : socket -> unit = "ocaml_ssl_flush"
@@ -253,7 +249,10 @@ let input_string ssl =
 
 let input_char ssl =
   let tmp = String.create 1 in
-    ignore (read ssl tmp 0 1); tmp.[0]
+    if read ssl tmp 0 1 <> 1 then
+      raise End_of_file
+    else
+      tmp.[0]
 
 let input_int ssl =
   let i = ref 0 in
